package org.drools.reteoo;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.kie.api.runtime.KieSession;
import org.kie.api.runtime.rule.EntryPoint;
import org.kie.api.KieServices;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNull;

/**
 * Tests different handling of non-existent entrypoints by PHREAK and RETE.
 */
public class EntryPointTest {

    private KieSession kieSession;

    @Before
    public void initialize() {
        KieServices ks = KieServices.Factory.get();
        kieSession = ks.getKieClasspathContainer().newKieSession("entryPointKSession");
    }

    @After
    public void release() {
        kieSession.dispose();
    }
    
    @Test
    public void testEntryPointAvailability() {
        EntryPoint entryPoint;

        entryPoint = kieSession.getEntryPoint("EventStream");
        assertNotNull(entryPoint);

        entryPoint = kieSession.getEntryPoint("declared");
        assertNotNull(entryPoint);

        entryPoint = kieSession.getEntryPoint("unused");
        assertNotNull(entryPoint);

        entryPoint = kieSession.getEntryPoint("nonexistent");
        // this fails with RETE
        assertNull(entryPoint);
    }

}
